Learn R Programming

spbal (version 1.0.1)

contains_feature: Check if the sf object contains a specified feature.

Description

Used to check if a simple file object contains a feature. This is an internal only function.

Usage

contains_feature(sf_object, feature_name)

Value

Returns TRUE if the simple file object sf_object contains the feature feature_name. Otherwise FALSE is returned.

Arguments

sf_object

Simple file object that we want to verify if it contains a feature called feature_name.

feature_name

The feature name we want to find in the simple file object sf_object.

Author

Phil Davies.