Learn R Programming

spbal (version 1.0.1)

is_sf_points: Check if an object is an sf points object.

Description

Tests if the object passed to the function is a sf points object or not. An internal only function.

Usage

is_sf_points(x)

Value

Either TRUE or FALSE.

Arguments

x

A probable sf points object.

Author

Phil Davies, Blair Robertson.

Details

Detect if an object is a sf points object or not.