Given some coordinates on [0,1)x[0,1), shift and scale them to the bounding box, and then rotate them given the bounding box rotation defined by the Master Sample.
rotate.scale.coords(coords, bb, back = TRUE)sf spatial points with projection defined in bb.
Output from RSHalton() to be converted to the spatial surface of interest.
Special shape file defining the bounding box with attributes for centroid and rotation.
Boolean for whether or not the rotation is back to the original rotated bounding box.
This function was first written by Paul van Dam-Bates for the package BASMasterSample.