Used to check if a simple file object contains a feature. This is an internal only function.
contains_feature(sf_object, feature_name)Returns TRUE if the simple file object sf_object contains the feature feature_name. Otherwise FALSE is returned.
Simple file object that we want to verify if it contains a feature called feature_name.
The feature name we want to find in the simple file object sf_object.
Phil Davies.