powered by
Tests if the object passed to the function is a sf points object or not. An internal only function.
is_sf_points(x)
Either TRUE or FALSE.
A probable sf points object.
Phil Davies, Blair Robertson.
Detect if an object is a sf points object or not.